@@ -121,6 +121,15 @@ Specifies is the API calls should be made over https.
 
 defaults to 0
 
+=item enable_attributes
+
+This flag adds support for attributes in the request. If enabled request
+data notes much be defined like so,
+
+myElement => { content => 'element content', myattr => 'attr value' }
+
+defaults to 0
+
 =back
 
 =head3 ALTERNATE CONFIG VIA ebay.ini
@@ -185,7 +194,6 @@ sub execute {
     $self->{response_content} = $self->_execute_http_request();
 
     if ( $DEBUG ) {
-        require Data::Dumper;
         print STDERR $self->{response_content};
     }
 
@@ -250,7 +258,12 @@ sub _get_request_body {
 
     my $xml = "<?xml version='1.0' encoding='utf-8'?>"
         . "<" . $self->{verb} . "Request xmlns=\"http://www.ebay.com/marketplace/search/v1/services\">"
-        . XMLout( $self->{call_data}, NoAttr => 1, KeepRoot => 1, RootName => undef )
+        . XMLout( 
+            $self->{call_data}, 
+            NoAttr => !$self->api_config->{enable_attributes},    
+            KeepRoot => 1, 
+            RootName => undef 
+        )
         . "</" . $self->{verb} . "Request>";
 
     return $xml; 
